@@ -26,7 +26,7 @@ inline
 void
 op_powmat::apply(Mat<typename T1::elem_type>& out, const Op<T1, op_powmat>& expr)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword y     =  expr.aux_uword_a;
   const bool  y_neg = (expr.aux_uword_b == uword(1));
@@ -47,7 +47,7 @@ inline
 bool
 op_powmat::apply_direct(Mat<typename T1::elem_type>& out, const Base<typename T1::elem_type,T1>& X, const uword y, const bool y_neg)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::elem_type eT;
   
@@ -72,7 +72,7 @@ op_powmat::apply_direct(Mat<typename T1::elem_type>& out, const Base<typename T1
     {
     const quasi_unwrap<T1> U(X.get_ref());
     
-    arma_debug_check( (U.M.is_square() == false), "powmat(): given matrix must be square sized" );
+    arma_conform_check( (U.M.is_square() == false), "powmat(): given matrix must be square sized" );
     
     op_powmat::apply_direct_positive(out, U.M, y);
     }
@@ -87,7 +87,7 @@ inline
 void
 op_powmat::apply_direct_positive(Mat<eT>& out, const Mat<eT>& X, const uword y)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N = X.n_rows;
   
@@ -96,7 +96,7 @@ op_powmat::apply_direct_positive(Mat<eT>& out, const Mat<eT>& X, const uword y)
   
   if(X.is_diagmat())
     {
-    arma_extra_debug_print("op_powmat: detected diagonal matrix");
+    arma_debug_print("op_powmat: detected diagonal matrix");
     
     podarray<eT> tmp(N);  // use temporary array in case we have aliasing
     
@@ -139,7 +139,7 @@ inline
 void
 op_powmat_cx::apply(Mat< std::complex<typename T1::pod_type> >& out, const mtOp<std::complex<typename T1::pod_type>,T1,op_powmat_cx>& expr)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::pod_type in_T;
   
@@ -161,7 +161,7 @@ inline
 bool
 op_powmat_cx::apply_direct(Mat< std::complex<typename T1::pod_type> >& out, const Base<typename T1::elem_type,T1>& X, const typename T1::pod_type y)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::elem_type in_eT;
   typedef typename T1::pod_type  in_T;
@@ -169,7 +169,7 @@ op_powmat_cx::apply_direct(Mat< std::complex<typename T1::pod_type> >& out, cons
   
   if( y == in_T(int(y)) )
     {
-    arma_extra_debug_print("op_powmat_cx::apply_direct(): integer exponent detected; redirecting to op_powmat");
+    arma_debug_print("op_powmat_cx::apply_direct(): integer exponent detected; redirecting to op_powmat");
     
     const uword y_val = (y < int(0)) ? uword(-y) : uword(y);
     const bool  y_neg = (y < int(0));
@@ -188,13 +188,13 @@ op_powmat_cx::apply_direct(Mat< std::complex<typename T1::pod_type> >& out, cons
   const quasi_unwrap<T1> U(X.get_ref());
   const Mat<in_eT>& A  = U.M;
   
-  arma_debug_check( (A.is_square() == false), "powmat(): given matrix must be square sized" );
+  arma_conform_check( (A.is_square() == false), "powmat(): given matrix must be square sized" );
   
   const uword N = A.n_rows;
   
   if(A.is_diagmat())
     {
-    arma_extra_debug_print("op_powmat_cx: detected diagonal matrix");
+    arma_debug_print("op_powmat_cx: detected diagonal matrix");
     
     podarray<out_eT> tmp(N);  // use temporary array in case we have aliasing
     
@@ -211,7 +211,7 @@ op_powmat_cx::apply_direct(Mat< std::complex<typename T1::pod_type> >& out, cons
   
   if(try_sympd)
     {
-    arma_extra_debug_print("op_powmat_cx: attempting sympd optimisation");
+    arma_debug_print("op_powmat_cx: attempting sympd optimisation");
     
     Col<in_T>  eigval;
     Mat<in_eT> eigvec;
@@ -229,7 +229,7 @@ op_powmat_cx::apply_direct(Mat< std::complex<typename T1::pod_type> >& out, cons
       return true;
       }
     
-    arma_extra_debug_print("op_powmat_cx: sympd optimisation failed");
+    arma_debug_print("op_powmat_cx: sympd optimisation failed");
     
     // fallthrough if optimisation failed
     }
